@@ -2,27 +2,30 @@
 #' 
 #' @description t.test based analysis of the fold change expression for any number of target genes.
 #' 
-#' @details The \code{qpcrTTEST} function applies a t.test based analysis to calculate fold change (\eqn{\Delta \Delta C_T} method) expression and returns related statistics for any number of target genes along with one or two 
-#' reference gene(s), that have been evaluated under control and treatment conditions. Sampling may be paired or 
-#' unpaired. Paired samples in quantitative PCR refer to two sample data that are collected from one set of individuals 
+#' @details The \code{qpcrTTEST} function applies a t.test based analysis to calculate 
+#' fold change (\eqn{\Delta \Delta C_T} method) expression and returns related statistics for any number of 
+#' target genes that have been evaluated under control and treatment conditions. Sampling may be paired or 
+#' unpaired. One or two reference genes can be used. Unpaired and paired samples are commonly analyzed 
+#' using unpaired and paired t-test, respectively.  \strong{NOTE:} Paired samples in quantitative PCR refer to two sample 
+#' data that are collected from one set of individuals 
 #' at two different conditions, for example before and after a treatment or at two different time points. While 
 #' for unpaired samples, two sets of individuals are used: one under untreated and the other set under treated 
 #' condition.  Paired samples allow to compare gene expression changes within the same individual, reducing 
-#' inter-individual variability. Unpaired and paired samples are commonly analyzed using unpaired and paired t-test, respectively.
+#' inter-individual variability. 
 #' @author Ghader Mirzaghaderi
 #' @export qpcrTTEST
 #' @import tidyr
 #' @import dplyr
 #' @import reshape2
 #' @import ggplot2
-#' @param x a data frame of 4 columns including Conditions, E (efficiency), Gene and Ct values (see example below). Biological replicates needs to be equal for all Genes. Each Ct value is the mean of technical replicates. Complete amplification efficiencies of 2 is assumed here for all wells but the calculated efficienies can be used instead.
+#' @param x a data frame of 4 columns including Conditions, E (efficiency), Gene and Ct values (see examples below). Biological replicates needs to be equal for all Genes. Each Ct value is the mean of technical replicates. Complete amplification efficiencies of 2 is assumed here for all wells but the calculated efficienies can be used instead. See \href{../doc/vignette.html}{\code{vignette}} for details about "data structure and column arrangement".
 #' @param paired a logical indicating whether you want a paired t-test.
 #' @param var.equal a logical variable indicating whether to treat the two variances as being equal. If TRUE then the pooled variance is used to estimate the variance otherwise the Welch (or Satterthwaite) approximation to the degrees of freedom is used.
 #' @param numberOfrefGenes number of reference genes. Up to two reference genes can be handled.
 #' @return A list of two elements:
 #' \describe{
 #'   \item{Row_data}{The row data including Genes and weighed delta Ct (wDCt) values.}
-#'   \item{Result}{Output table including the Fold Change values, lower and upper confidence interval and the pvalues from compairing fold change between treated and non-treated conditions}
+#'   \item{Result}{Output table including the Fold Change values, lower and upper confidence interval, pvalue and standard error with the lower and upper limits.}
 #' }
 #' For more information about the test procedure and its arguments,
 #' refer \code{\link[stats]{t.test}}, and \code{\link[stats]{lm}}.
@@ -57,12 +60,6 @@
 #'           numberOfrefGenes = 2, 
 #'           var.equal = TRUE)
 #'  
-#'           
-#' qpcrTTESTplot(Taylor_etal2019, 
-#'               numberOfrefGenes = 2, 
-#'               var.equal = TRUE,
-#'               y.axis.adjust = -0.7,
-#'               y.axis.by = 0.5)
 #'
 #'
 
@@ -129,8 +126,16 @@ qpcrTTEST <- function(x,numberOfrefGenes, paired = FALSE, var.equal = TRUE) {
                     round(stats::sd(subset[(r+1):(2*r),i])/sqrt(r), 4))
 
     }
+    res <- as.data.frame(res)
+    res$FC <- as.numeric(res$FC)
+    res$se <- as.numeric(res$se)
+    res$dif <- NULL
+    res <- data.frame(res, 
+                      Lower.se = round(2^(log2(res$FC) - res$se), 4), 
+                      Upper.se = round(2^(log2(res$FC) + res$se), 4))
+    
     Raw_df <- melt(subset, value.name = "wDCt")[-1]
-    res <- list(Raw_data = Raw_df, Result = data.frame(res))
+    res <- list(Raw_data = Raw_df, Result = res)
     return(res)
   }
 }
